@@ -20,10 +20,15 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include <glib-object.h>
-
 #ifndef __TP_UTIL_H__
 #define __TP_UTIL_H__
+#define __TP_IN_UTIL_H__
+
+#include <glib-object.h>
+
+#include <telepathy-glib/verify.h>
+
+#define tp_verify_statement(R) ((void) tp_verify_true (R))
 
 G_BEGIN_DECLS
 
@@ -63,6 +68,12 @@ gchar *tp_escape_as_identifier (const gchar *name);
 
 gboolean tp_strv_contains (const gchar * const *strv, const gchar *str);
 
+gint64 tp_g_key_file_get_int64 (GKeyFile *key_file, const gchar *group_name,
+    const gchar *key, GError **error);
+guint64 tp_g_key_file_get_uint64 (GKeyFile *key_file, const gchar *group_name,
+    const gchar *key, GError **error);
+
 G_END_DECLS
 
+#undef  __TP_IN_UTIL_H__
 #endif /* __TP_UTIL_H__ */
